==> xld-openshift-plugin-8.5.6.jar: xld/openshift/deploymentconfig/create_update_wait.py <==
from xld.openshift.connector import OpenShiftConnector
from xld.openshift.resource_provider import DeploymentConfigResourceProvider
from xld.openshift.deploymentconfig.deployment_config_helper import DeploymentConfigHelper

result = "SUCCESS"
connector = OpenShiftConnector(deployed.container.container)
deployment_config_dict = DeploymentConfigHelper.read_deployment_config(deployed)

deployment_config_resource_provider = DeploymentConfigResourceProvider(deployed.container)
deployment_config = deployment_config_resource_provider.filter_resources_by_definition(namespace=deployed.container.projectName,
                                                                                       resource_definition=deployment_config_dict)


# hack method to fail process if pods are not at a ready status. result 'FAIL' does not work
def processFail():
    print ("None of the pods were at a ready status after reaching the max number of retries. \n")
    raise Exception(
        "Max number of retries reached. Please verify if readiness probe check is correct or increase the number 'Readiness Probe Retry' in ci properties... \n")
    # fails the deployment here
    exit(1)


def processItem(item):
    print("#####")
    print("DeploymentConfig Status:")
    print("- Replica(s) wanted: %s" % item.spec.replicas)
    print("- readyReplicas: %s" % item.status.ready_replicas)
    print("- updatedReplicas: %s" % item.status.updated_replicas)
    print("- unavailableReplicas: %s" % item.status.unavailable_replicas)
    print("- availableReplicas: %s" % item.status.available_replicas)
    
    if item.status.available_replicas != item.spec.replicas or item.status.unavailable_replicas > 0:

        if deployed.readinessProbeRetry > 0:
            print(
                "Waiting for DeploymentConfig's {0} to have pods in running state, retries left: {1} (Approx {2} seconds)".format(
                    item.metadata.name, deployed.readinessProbeRetry, deployed.readinessProbeRetry * 5))
            deployed.readinessProbeRetry -= 1
            return "RETRY"
        else:
            processFail()

    return "SUCCESS"


for item in deployment_config.items:
    if deployed.validatePodsCreation:
        result = processItem(item)

==> xld-openshift-plugin-9.0.0.jar: xld/openshift/deploymentconfig/create_update_wait.py <==
from xld.openshift.connector import OpenShiftConnector
from xld.openshift.resource_provider import DeploymentConfigResourceProvider
from xld.openshift.deploymentconfig.deployment_config_helper import DeploymentConfigHelper

result = "SUCCESS"
connector = OpenShiftConnector(deployed.container.container)
deployment_config_dict = DeploymentConfigHelper.read_deployment_config(deployed)

with DeploymentConfigResourceProvider(deployed.container) as deployment_config_resource_provider:
    deployment_config = deployment_config_resource_provider.filter_resources_by_definition(
        namespace=deployed.container.projectName,
        resource_definition=deployment_config_dict)


# hack method to fail process if pods are not at a ready status. result 'FAIL' does not work
def processFail():
    print ("None of the pods were at a ready status after reaching the max number of retries. \n")
    raise Exception(
        "Max number of retries reached. Please verify if readiness probe check is correct or increase the number 'Readiness Probe Retry' in ci properties... \n")
    # fails the deployment here
    exit(1)


def processItem(item):
    if item.status.readyReplicas is None or item.status.readyReplicas < item.spec.replicas:
        if deployed.readinessProbeRetry > 0:
            print(
                "Waiting for DeploymentConfig's {0} to have pods in running state, retries left: {1} (Approx {2} seconds)".format(
                    item.metadata.name, deployed.readinessProbeRetry, deployed.readinessProbeRetry * 5))
            deployed.readinessProbeRetry -= 1
            return "RETRY"

        else:
            processFail()
    return "SUCCESS"


for item in deployment_config.items:
    if (deployed.validatePodsCreation):
        result = processItem(item)
